Contributor Code of Conduct
======================

As contributors and maintainers of this project, we pledge to respect
everyone who contributes by posting issues, updating documentation,
submitting pull requests, providing feedback in comments, and any other
activities.

Communication through any project channels (GitHub, mailing lists,
Twitter, and so on) must be constructive and never resort to personal
attacks, trolling, public or private harassment, insults, or other
unprofessional conduct.

We promise to extend courtesy and respect to everyone involved in this
project, regardless of gender, gender identity, sexual orientation,
disability, age, race, ethnicity, religion, or level of experience. We
expect anyone contributing to this project to do the same.

If any member of the community violates this code of conduct, the
maintainers of this project may take action, including removing issues,
comments, and PRs or blocking accounts, as deemed appropriate.

If you are subjected to or witness unacceptable behavior, or have any
other concerns, please communicate with us.

If you have suggestions to improve the code of donduct, please submit
an issue or PR.


**Attribution**

This Code of Conduct is adapted from the VMware Clarity project, available at this page: https://github.com/vmware/clarity/blob/master/CODE_OF_CONDUCT.md
